@@ -16,11 +16,11 @@ impl std::ops::Deref for FontVec {
     }
 }
 
-impl std::convert::TryInto<FontVec> for Vec<u8> {
+impl std::convert::TryFrom<Vec<u8>> for FontVec {
     type Error = glyph_brush::ab_glyph::InvalidFont;
 
-    fn try_into(self) -> Result<FontVec, Self::Error> {
-        Ok(FontVec(ABFontVec::try_from_vec(self)?))
+    fn try_from(value: Vec<u8>) -> Result<Self, Self::Error> {
+        Ok(Self(ABFontVec::try_from_vec(value)?))
     }
 }
 
@@ -168,13 +168,13 @@ impl Text {
                         color: extra.color,
                     },
                     super::Vertex2D {
-                        position: [gl_rect.min.x as f32, gl_rect.max.y as f32],
-                        uv: [tex_coords.min.x, tex_coords.max.y],
+                        position: [gl_rect.max.x as f32, gl_rect.max.y as f32],
+                        uv: [tex_coords.max.x, tex_coords.max.y],
                         color: extra.color,
                     },
                     super::Vertex2D {
-                        position: [gl_rect.max.x as f32, gl_rect.max.y as f32],
-                        uv: [tex_coords.max.x, tex_coords.max.y],
+                        position: [gl_rect.min.x as f32, gl_rect.max.y as f32],
+                        uv: [tex_coords.min.x, tex_coords.max.y],
                         color: extra.color,
                     },
                 ],
