@@ -20,6 +20,16 @@ pub struct GraphicsLock<'a, 'b> {
     dl: DrawList<'b>,
 }
 
+impl GraphicsLock<'_, '_> {
+    pub fn ctx_mut(&mut self) -> &mut Context {
+        self.ctx
+    }
+
+    pub fn gfx(&self) -> &Graphics {
+        self.gfx
+    }
+}
+
 impl<'b> std::ops::Deref for GraphicsLock<'_, 'b> {
     type Target = DrawList<'b>;
 
@@ -119,6 +129,10 @@ impl Graphics {
         self.viewport = viewport;
     }
 
+    pub fn viewport(&self) -> &solstice::viewport::Viewport<i32> {
+        &self.viewport
+    }
+
     pub fn set_scissor(&mut self, scissor: Option<solstice::viewport::Viewport<i32>>) {
         self.scissor = scissor;
     }
@@ -432,18 +446,19 @@ where
 }
 
 #[derive(Debug, Clone, PartialEq)]
-pub struct Geometry<'a, V> {
+pub struct Geometry<'a, V, I = u32> {
     vertices: MaybeOwned<'a, V>,
-    indices: Option<MaybeOwned<'a, u32>>,
+    indices: Option<MaybeOwned<'a, I>>,
 }
 
-impl<'a, V> Geometry<'a, V> {
-    pub fn new<IV: Into<std::borrow::Cow<'a, [V]>>, II: Into<std::borrow::Cow<'a, [u32]>>>(
+impl<'a, V, I> Geometry<'a, V, I> {
+    pub fn new<IV: Into<std::borrow::Cow<'a, [V]>>, II: Into<std::borrow::Cow<'a, [I]>>>(
         vertices: IV,
         indices: Option<II>,
     ) -> Self
     where
         [V]: std::borrow::ToOwned<Owned = Vec<V>>,
+        [I]: std::borrow::ToOwned<Owned = Vec<I>>,
     {
         Self {
             vertices: vertices.into().into(),
@@ -610,6 +625,7 @@ where
     Data(Geometry<'a, V>),
     VertexMesh(solstice::Geometry<&'a solstice::mesh::VertexMesh<V>>),
     IndexedMesh(solstice::Geometry<&'a solstice::mesh::IndexedMesh<V, u32>>),
+    IndexedMeshU16(solstice::Geometry<&'a solstice::mesh::IndexedMesh<V, u16>>),
     MultiMesh(solstice::Geometry<&'a solstice::mesh::MultiMesh<'a>>),
 }
 
@@ -630,8 +646,9 @@ where
         use solstice::Renderer;
         match self {
             MeshVariant::Data(data) => data.draw(meshes, ctx, shader, settings),
-            MeshVariant::VertexMesh(geometry) => ctx.draw(shader, &geometry, settings),
-            MeshVariant::IndexedMesh(geometry) => ctx.draw(shader, &geometry, settings),
+            MeshVariant::VertexMesh(geometry) => ctx.draw(shader, geometry, settings),
+            MeshVariant::IndexedMesh(geometry) => ctx.draw(shader, geometry, settings),
+            MeshVariant::IndexedMeshU16(geometry) => ctx.draw(shader, geometry, settings),
             MeshVariant::MultiMesh(geometry) => ctx.draw(shader, &geometry, settings),
         }
     }
@@ -691,6 +708,15 @@ where
     }
 }
 
+impl<'a, V> From<solstice::Geometry<&'a solstice::mesh::IndexedMesh<V, u16>>> for MeshVariant<'a, V>
+where
+    V: solstice::vertex::Vertex,
+{
+    fn from(v: solstice::Geometry<&'a solstice::mesh::IndexedMesh<V, u16>>) -> Self {
+        Self::IndexedMeshU16(v)
+    }
+}
+
 impl<'a, V> From<solstice::Geometry<&'a solstice::mesh::MultiMesh<'a>>> for MeshVariant<'a, V>
 where
     V: solstice::vertex::Vertex,
